function checkstart(self, fields, startidx, newfig)
    % CHECKSTART Plot a data filed alongside the detected start time for verification.
    %   This function can either plot a specific field or all unique fields in Raw and Cleaned data.
    % -----
    %
    % Syntax:
    %   GenericData.CHECKSTART(field, startidx) plots the initial instants of the raw data for the
    %   selected field and add a visual marker for the calculated starting index.
    %
    % Inputs:
    %   field    : Field to plot
    %   startidx : Starting motion index
    %
    % Output:
    %   plot(s) of raw and cleaned data
    %
    % See also: TunnelData, ArduData.
    %
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants
    FIGNME = 'GenericData - Checkstart';

    if nargin < 4
        newfig = true;
    end

    if newfig
        close(findobj('type', 'figure', 'name', FIGNME));
        figure('Name', FIGNME);
    end

    for iField = 1:numel(fields)
        thisField = fields{iField};
        subplot(1, 2, iField);
        self.plotstart(thisField, startidx);
    end

end
