function plot(self, field)
    % PLOT Plot the raw data alongside the cleaned one.
    %   This function can either plot a specific field or all unique fields in Raw and Cleaned data.
    % -----
    %
    % Syntax:
    %   GenericData.PLOTRAW() plots all unique fields found in raw and cleaned data.
    %
    %   GenericData.PLOTRAW(field) plots the raw data for the field `field` alongside its cleaned
    %   equivalent
    %
    % Inputs:
    %   field : (optional) Field to plot
    %
    % Output:
    %   plot(s) of raw and cleaned data
    %
    % See also: TunnelData, ArduData.
    %
    % ----------------------------------------------------------------------------------------------
    % FIXME: (M) Improve base line options
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Find all unique properties amongs raw and cleaned data
    rawVar = self.Raw.Properties.VariableNames;
    cleanedVar = self.Cleaned.Properties.VariableNames;
    uniqueVar = unique([rawVar, cleanedVar]);

    if nargin < 2
        for field = uniqueVar
            if ~strcmpi(field{:}, 'time')
                comprefield(self, field{:});
            end
        end
    else
        comprefield(self, field);
    end
end

function comprefield(self, field)

    figure('Name', field);
    title(field);

    plotfield(self.Raw, field, 'raw');
    hold on;
    plotfield(self.Cleaned, field, 'cleaned');
    legend('Interpreter', 'none');

end

function plotfield(Table, field, leName)
    colors = get(gca, 'colororder');

    if strcmpi(leName, 'cleaned')
        lineCol = colors(2, :);
    else
        lineCol = colors(1, :);
    end

    if any(ismember(Table.Properties.VariableNames, field))
        plot(Table.(field), 'color', lineCol, 'DisplayName', [field, ' (', leName, ')']);
    end
end
