function plotstart(self, field, startidx)
    % PLOTSTART Plot a data filed alongside a line corresponding to the start of the motion.
    % -----
    %
    % Syntax:
    %   GenericData.PLOTSTART(field, startidx) plots the initial instants of the cleaned data for
    %   the selected field and add a visual marker for the calculated starting index.
    %
    % Inputs:
    %   field    : Field to plot
    %   startidx : Starting motion index
    %
    % Output:
    %   plot(s) of raw and cleaned data
    %
    % See also: TunnelData, ArduData.
    %
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    hold on;
    plot(self.Cleaned.(field)(1:4 * startidx));
    xline(startidx, 'r');

end
