function averageall(self)
    % AVERAGE Average normalized periods into a single one
    %   .
    % -----
    %
    % Syntax:
    %   Periods.average()
    %
    % Inputs:
    %   self : a Periods object with populated self.Raw property.
    %
    % Output:
    %    self.Avg :
    %
    % See also: Periods, Periods.normalize, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Input checks
    % TODO: We should check if self.Normalized is populated properly

    % --- Averaging normalized period
    [avgTable, lowTable, highTable] = averagetablestruct(self.Normalized, true, ...
                                                         self.PERCENTILE(1), 'median');

    % Ouput
    self.Avg.MedianData = avgTable;
    self.Avg.LowPcData = lowTable;
    self.Avg.HighPcData = highTable;
end
