function plotaverage(self, dataName, newFig)
    % PLOTAVERAGE Plot the averaged data.
    %   .
    % -----
    %
    % Syntax:
    %   Periods.average()
    %
    % Inputs:
    %   self : a Periods object with populated self.Raw property.
    %
    % Output:
    %    self.Avg :
    %
    % See also: Periods, Periods.normalize, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Defaults and constants

    % --- Input checks
    % TODO: We should check if Periods.baseTable is populated
    if nargin < 3
        newFig = false;
    end

    if newFig
        figname = sprintf('Periods - Average (%s)', self.setPosition);
        close(findobj('type', 'figure', 'name', figname));
        figure('Name', figname);
    end

    avgData = self.Avg.MedianData;
    lowPc = self.Avg.LowPcData;
    highPc = self.Avg.HighPcData;

    % Plot percentile range first as background
    channelplot(avgData.time, highPc.(dataName), lowPc.(dataName), avgData.(dataName));

end
