function plotraw(self, dataName, newFig)
    % PLOTRAW Plot the averaged data.
    %   .
    % -----
    %
    % Syntax:
    %   Periods.plotraw()
    %
    % Inputs:
    %   self : a Periods object with populated self.Raw property.
    %
    % Output:
    %    self.Avg :
    %
    % See also: Periods, Periods.normalize, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Defaults and constants
    N_PERIODS = 30;

    % --- Input checks
    % TODO: We should check if Periods.baseTable is populated
    if nargin < 3
        newFig = false;
    end

    if newFig
        figname = sprintf('Periods - Raw (%s)', self.setPosition);
        close(findobj('type', 'figure', 'name', figname));
        figure('Name', figname);
    end

    % Limit plot to N periods (save time and easier to visualize)
    idx = find(self.baseTable.time > self.Raw(N_PERIODS).Data.time(end), 1);

    % Plot
    plot(self.baseTable.time(1:idx), self.baseTable.(dataName)(1:idx));
    hold on;
    for iPer = 1:N_PERIODS
        xline(self.Raw(iPer).Data.time(1), 'r');
    end
    grid on;

end
