function self = prune(self, pruneType)
    % PRUNE Prune some redundant data to save disk space and improve loading time
    %   The initial data is duplicated a lot. This can duplication can be improved by pruning the
    %   redundant data everywhere possible. The pruned data can then be recreated/accessed later on
    %   from the detailed data if needed.
    %
    % -----
    %
    % Syntax:
    %   Periods.prune(pruneType) Prune the Periods object according to the pruneType used.
    %   The pruneType can be an array of different pruning strategies.
    %
    %
    % Inputs:
    %   self      : a Periods object. Ideally fully formed and calculated so the pruned data can
    %               be (partially) reconstructed from remaining data.
    %   pruneType : Type of pruning to use. Can be a character vector or a list of pruning types.
    %               The following options are implemented:
    %                   - baseData   : clear Periods.baseTable
    %                   - raw        : clear Periods.Raw
    %                   - normalized : clear Periods.Normalized
    %
    % Output:
    %   self : The original Periods object, with cleared fields.
    %
    % Seel also: Periods, TestResults.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Input validation
    pruneType = string(pruneType);

    % --- Pruning

    for iPrune = pruneType
        if any(strcmpi(iPrune, {'baseData', 'base'}))
            self.baseTable = [];
        elseif strcmpi(iPrune, 'raw')
            self.Raw = [];
        elseif strcmpi(iPrune, 'normalized')
            self.Normalized = [];
        elseif any(strcmpi(iPrune, {'average', 'avg', 'averaged'}))
            self.Avg = [];
        end
    end

end
