function trim(self, nbToKeep)
    % TRIM Trim the number of cycles saved by removing the last ones
    %   This ensures that we focus on the same number of cycles for both front and aft set.
    %   Normally they should be pretty similar, but due to discrepencies in the frequency, sometimes
    %   one set has one or two more cycles over the length of the acquisition.
    % -----
    %
    % Syntax:
    %   Periods.trim(nbToKeep) Removes the last cycles from the data tables so we end up with only
    %   nbToKeep cycles.
    %
    % Inputs:
    %   self : a Periods object.
    %
    % Output:
    %    self.Raw, self.Normalized with correct number of cycles
    %
    % See also: Periods, Periods.splitbase, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Remove extra cycles
    if nbToKeep > numel(self.Raw)
        warning('Periods:trim:notenoughelements', ...
                ['Not enough elements to trim.', ...
                 'Impossible to keep %d cycles as we only have %d ', ...
                 'cycles in the original data.\n', ...
                 'Nothing was changed.'], nbToKeep, numel(self.Raw));
    elseif nbToKeep + 1 <= numel(self.Raw)
        self.Raw(nbToKeep + 1:end) = [];
        self.Normalized(nbToKeep + 1:end) = [];
    end

end
