function checkstart(self, arduStartIdx, tunnelStartIdx)
    % CHECKSTART Check cleanded test data to make sure it is properly synced/merged.
    %   This function plots the first instants of the cleaned data and the detected starting point
    %   to better visualize if everything is properly in sync.
    %
    % Note:
    %   The data is plotted in a 2-2 subpolot:
    %        - columns indicate FRONT and AFT wing
    %        - raw indicate ANGLE and FZ (lift)
    % -----
    %
    % Syntax:
    %   TestCase.CHECKRAW() plots the angle and z-axis load for the front and aft wings with the
    %   starting point detected automatically.
    %
    % Inputs:
    %   self : a TestCase object
    %
    % Output:
    %    A 2-2 subplot figure with all the relevant data.
    %
    % See also: TestCase, TunnelData, ArduData.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants
    PRINT_VALUES = true;
    FIGNAME = 'TestCase - Checkstart';

    close(findobj('type', 'figure', 'name', FIGNAME));

    if PRINT_VALUES
        fprintf('arduStartIdx: %d\n', arduStartIdx);
        fprintf('tunnelStartIdx: %d\n', tunnelStartIdx);
    end

    figure('Name', FIGNAME);
    ax1 = subplot(2, 2, 1); % Top Left
    self.ArduDat.plotstart('angleF', arduStartIdx);
    ylim([-20, 40]);
    ax2 = subplot(2, 2, 2); % Top Right
    self.ArduDat.plotstart('angleA', arduStartIdx);
    ylim([-20, 40]);
    ax3 = subplot(2, 2, 3); % Bottom Left
    self.TunnelDat.plotstart('Fz_front', tunnelStartIdx);
    ax4 = subplot(2, 2, 4); % Bottom Right
    self.TunnelDat.plotstart('Fz_aft', tunnelStartIdx);

    linkaxes([ax1, ax2], 'xy');
    linkaxes([ax3, ax4], 'x');

end
