function exportcsv(self)
    % EXPORTCSV Export the TestCase.Data table to a CSV.
    %
    % Note:
    %   The file will be saved in
    %       ../data/cleaned/<campaign_name>/<identification_name>_<line>.csv
    % -----
    %
    % Syntax:
    %   TestCase.exportcsv() save the TestCase.Data into a CSV file.
    %
    % Inputs:
    %   none
    %
    % Output:
    %   CSV file with the TestCase.Data table
    %
    % See also: TestCase, TunnelData, ArduData.
    %
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants
    OVERWRITE = true;

    % Get directory and proper filename
    saveDir = fileparts(self.saveFileName);
    saveFile = [self.saveFileName, '.csv'];
    chkdir(saveDir);

    % Save CSV
    if ~exist(saveFile, 'file') || OVERWRITE
        writetable(self.Data, saveFile);
    end
end
