function plotavg(self, dataNames, figTitle)
    % PLOTRAW Plot cleanly the average period
    %   .
    % -----
    %
    % Syntax:
    %   TestResult.plotavg()
    %
    % Inputs:
    %   self : TODO.
    %
    % Output:
    %     :
    %
    % See also: Periods, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Defaults and constants
    FIGNAME = 'Analysis - Avg';

    % --- Input checks
    if nargin < 3
        figTitle = self.strcond('title', 'meanfreq');
    end

    close(findobj('type', 'figure', 'name', FIGNAME));

    % --- Make figures

    figure('Name', FIGNAME);
    sgtitle(figTitle); % Main figure title

    for i = 1:numel(dataNames)

        switch dataNames{i}
            case {'angle'}
                yUnit = 'deg';
            case {'power'}
                yUnit = 'W';
            case {'Fx', 'Fy', 'Fz'}
                yUnit = 'N';
            case {'Mx', 'My', 'Mz'}
                yUnit = 'N·m';
        end

        % Front Set
        ax(i, 1) = subplot(numel(dataNames), 2, 2 * i - 1); % Top Left
        self.PeriodsF.plotaverage(dataNames{i}, false);
        if i == 1
            title('Front');
        end
        if i == numel(dataNames)
            xlabel('Time [s]');
        end
        ylabel(sprintf('%s [%s]', dataNames{i}, yUnit));
        grid on;

        % Aft Set
        ax(i, 2) = subplot(numel(dataNames), 2, 2 * i); % Top Right
        self.PeriodsA.plotaverage(dataNames{i}, false);
        if i == 1
            title('Aft');
        end
        if i == numel(dataNames)
            xlabel('Time [s]');
        end
        grid on;

        linkaxes([ax(i, 1), ax(i, 2)], 'y');

    end

    % Axes setup
    linkaxes(ax, 'x');
    xlim([0, self.PeriodsF.Avg.MedianData.time(end)]);

end
