function plotoffsets(self, dataNames, plotType, newFig)
    % PLOTOFFSETS Plot some data for all phase offset values.
    %   .
    % -----
    %
    % Syntax:
    %   TestResult.plotoffsets()
    %
    % Inputs:
    %   self : TODO.
    %
    % Output:
    %     :
    %
    % See also: Periods, TestCase.

    % ----------------------------------------------------------------------------------------------
    % TODO: Better plot the channel rather than error bars
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Input checks
    if nargin < 3
        plotType = 'channel';
    end
    if nargin < 4
        newFig = false;
    end

    if newFig
        figname = sprintf('TestResult - Phase offset');
        close(findobj('type', 'figure', 'name', figname));
        figure('Name', figname);
    end

    % Plot
    ax = zeros(numel(dataNames), 2);
    for i = 1:numel(dataNames)
        thisData = dataNames{i};

        switch thisData
            case {'angle'}
                yUnit = 'deg';
            case {'power'}
                yUnit = 'W';
            case {'Fx', 'Fy', 'Fz'}
                yUnit = 'N';
            case {'Mx', 'My', 'Mz'}
                yUnit = 'N·m';
        end

        % Front Set
        ax(i, 1) = subplot(numel(dataNames), 2, 2 * i - 1); % Top Left
        if strcmpi(plotType, 'channel')
            y_mean = self.OffsetGroups.ovMean.Front.(thisData);
            y_high = y_mean + self.OffsetGroups.ovStd.Front.(thisData);
            y_low = y_mean - self.OffsetGroups.ovStd.Front.(thisData);
            channelplot(self.OffsetGroups.offset, ...
                        y_high, y_low, y_mean);
        else
            errorbar(self.OffsetGroups.offset, ...
                     self.OffsetGroups.ovMean.Front.(thisData), ...
                     self.OffsetGroups.ovStd.Front.(thisData));
        end
        if i == 1
            title('Front');
        end
        if i == numel(dataNames)
            xlabel('Phase offset [deg]');
        end
        ylabel(sprintf('%s [%s]', dataNames{i}, yUnit));
        grid on;

        % Aft Set
        ax(i, 2) = subplot(numel(dataNames), 2, 2 * i); % Top Right
        if strcmpi(plotType, 'channel')
            y_mean = self.OffsetGroups.ovMean.Aft.(thisData);
            y_high = y_mean + self.OffsetGroups.ovStd.Aft.(thisData);
            y_low = y_mean - self.OffsetGroups.ovStd.Aft.(thisData);
            channelplot(self.OffsetGroups.offset, ...
                        y_high, y_low, y_mean);
        else
            errorbar(self.OffsetGroups.offset, ...
                     self.OffsetGroups.ovMean.Aft.(thisData), ...
                     self.OffsetGroups.ovStd.Aft.(thisData));
        end
        if i == 1
            title('Aft');
        end
        if i == numel(dataNames)
            xlabel('Phase offset [deg]');
        end
        grid on;

        linkaxes([ax(i, 1), ax(i, 2)], 'y');

    end

    linkaxes(ax, 'x');
    xlim([-180, 180]);

end
