function plotraw(self, dataName, figTitle)
    % PLOTRAW Plot cleanly the Raw data
    %   .
    % -----
    %
    % Syntax:
    %   TestResult.plotraw()
    %
    % Inputs:
    %   self : TODO.
    %
    % Output:
    %     :
    %
    % See also: Periods, TestCase.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/mecharaptor/data-processing
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Defaults and constants
    figname = sprintf('Analysis - Raw (%s)', dataName);

    % --- Input checks
    if nargin < 3
        figTitle = self.strcond('title', 'meanfreq');
    end

    close(findobj('type', 'figure', 'name', figname));

    % --- Make figures
    figure('Name', figname);
    sgtitle(figTitle); % Main figure title

    % Front Set
    ax1 = subplot(1, 2, 1); % Top Left
    self.PeriodsF.plotraw(dataName, false);
    title('Front Angle');
    ylabel('Angle [deg]');
    xlabel('Time [s]');
    grid on;

    % Aft Set
    ax2 = subplot(1, 2, 2); % Top Right
    self.PeriodsA.plotraw(dataName, false);
    title('Aft Angle');
    xlabel('Time [s]');
    grid on;

    % Axes setup
    linkaxes([ax1, ax2], 'xy');
    ylim([-20, 40]);
    set([ax1, ax2], 'TickDir', 'out');
end
