% FIG_SETUP Setup everything for the figure creation
%   This script sets up the environment for plotting.
% -----
%
% Syntax:
%   FIG_SETUP;
%
% Inputs:
%   None
% Output:
%   Environment is properly set.
%
% See also: fig_intro, fig_single, fig_tandemsteady, fig_tandemfrontflap, fig_tandemfull.

% ----------------------------------------------------------------------------------------------
% matlab2tikz: https://github.com/matlab2tikz/matlab2tikz
% ----------------------------------------------------------------------------------------------
% (c) Copyright 2022-2024 University of Liege
% Author: Thomas Lambert <t.lambert@uliege.be>
% ULiege - Aeroelasticity and Experimental Aerodynamics
% MIT License
% Repo: https://gitlab.uliege.be/mecharaptor/data-processing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% --- Cleanup, imports and environment setting
clearvars -except RL;  % Do not clear ResultLoader (avoid reloading results)
close all;
clc;
addpath(genpath('.')); % `src/` directory and its subdirs
setcwdhere();

% Use latex everywhere by default
set(0, 'defaulttextinterpreter', 'latex');
% Remove latex warning in labels, titles, legends, etc
warning('off', 'MATLAB:handle_graphics:exceptions:SceneNode');

% --- Defaults and constants
FORCE_RELOAD = 'false';  % If 'reload', force reload the results

FIG_TYPE = 'dissert'; % Can either be 'dissertation' or 'presentation'
LINE_WIDTH = 1.2;
SAVE_FIGURES = true;
KEEP_FIGURES_OPEN = false;

MATLAB_FIG_DIR = '../figures/methodo/';
THESIS_FIG_DIR = '../../../../../01-Thesis/figures/mecharaptor';

DEBUG = false;
VERBOSITY = 2; % Verbosity level (1: warnings & errors, 2: info, 3:debug)

%% Set proper colormap
cmap = Uliegecolors.map();

%% Load data
% Data is loaded on the fly when needed.
% We just instantiate the object here first if needed

if ~exist('RL', 'var')
    RL = ResLoader;
end
