function logmsg(msg, logLvl, verbo)
    % CONSOLELOG Display a message in the console, depending on the verbosity level required.
    % -----
    %
    % Syntax:
    %   logmsg(msg, logLvl, verbo) display the message in msg if the current verobsity is lower or
    %   equal to the message criticality level.
    %
    % Inputs:
    %   msg    : The message to log (display in the console).
    %   logLvl : The message criticality level:
    %               0 - Critical error
    %               1 - Warning
    %               2 - Info
    %               3 - Debug
    %   verbo  : The verbosity level desired by the user.
    %
    % See also: microraptor, template.
    %
    % <a href="https://gitlab.uliege.be/am-dept/tlambert/matlab_uvlm">Complete documentation</a>

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/am-dept/tlambert/matlab_uvlm
    % Docs: https://gitlab.uliege.be/am-dept/tlambert/matlab_uvlm
    % Issues: https://gitlab.uliege.be/am-dept/tlambert/matlab_uvlm/-/issues
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % --- Imports and input options

    validateattributes(msg, {'string', 'char'}, {}, mfilename, 'msg', 1);
    validateattributes(logLvl, {'numeric'}, ...
                       {'integer', 'nonnegative', '<=', 4}, ...
                       mfilename(), 'logLvl', 2);
    validateattributes(verbo, {'numeric'}, ...
                       {'integer', 'nonnegative', '<=', 4}, ...
                       mfilename(), 'verbo', 3);

    % --- Display message in console if appropriate

    if verbo >= logLvl

        msg = string(msg);

        if logLvl < 1
            msgCol = 2;
        else
            msgCol = 1;
        end

        for i = 1:numel(msg)
            fprintf(msgCol, '%s\n', msg{i});
        end
    end

end
