function frac = fracpart(x)
    % FRACPART Fractional part (decimal part) of a real number.
    %   This function works on both negative and positive numbers.
    % -----
    %
    % Syntax:
    %   frac = fracpart(x) returns the fractional part of real number x.
    %
    % Inputs:
    %   x : An real number (or array of real numbers).
    %
    % Output:
    %   frac : the fractional part of the input number(s).
    %
    % Example:
    %   fracpart(1.38) % returns 0.38
    %   fracpart([-4.2, 3.8]) % returns [-0.2, 0.8]

    % ----------------------------------------------------------------------------------------------
    % Source: https://en.wikipedia.org/wiki/Fractional_part
    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Input check
    validateattributes(x, {'numeric'}, {'real'}, mfilename(), 'x', 1);

    % Fractional part
    frac = x - floor(abs(x)) .* sign(x);

end
