function setcwdhere()
    % SETCWDHERE Reset the current working directory to the same as the calling file.
    %   This function ensures that the current working directory is properly set, so relative path
    %   will always point to the correct location.
    % Note:
    %   This is mainly useful when saving figures and results for instance.
    % -----
    %
    % Syntax:
    %   setcwdhere() sets the cwd to the one of the calling function. If this function is called
    %   directly from the command line, nothing is done.
    %
    % Inputs:
    %   None.
    %
    % Output:
    %   None.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Use dbstack to determine calling order
    %   dbstack(1): This function
    %   dbstack(2): The function calling this function
    %   dbstack(N): The function calling N-1

    stack = dbstack;

    if numel(stack) > 1 % Function called from somewhere else

        % Get calling function path
        fullFileName = which(stack(2).file);
        path = fileparts(fullFileName);

        % Set path properly
        cd(path);
    end

end
