function trimmed = trimvect(vect, trimPc, trimType)
    % TRIMVECT Trim the head or tail of a vector.
    %   Removes the head or the tail of a vector based on a trimming percentage.
    %
    % Note:
    %   Trimming is greedy: if the trim percentage does not land on an integer index, this function
    %   will always trim one more element, leading to an actual trimmed portion a bit larger.
    % -----
    %
    % Syntax:
    %   TODO
    %
    % Inputs:
    %   TODO
    %
    % Output:
    %   TODO
    %
    % See also: plot.

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2024 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants

    if nargin < 3
        trimType = 'head';
    end
    validatestring(trimType, {'head', 'tail'}, mfilename(), 'trimType');

    % No need to trim empty vector
    if isempty(vect)
        trimmed = vect;
        return
    end

    switch trimType
        case 'head' % Remove head of a vector
            trimmed = vect(ceil(end * trimPc / 100):end);
        case 'tail' % Remove tail of a vector
            trimmed = vect(1:end - ceil(end * trimPc / 100));
    end

end
